==> nip2_7.24.1.orig.tar.gz: nip2-7.24.1/src/toggleview.h <==
/* a toggleview button in a workspace
 */

/*

    Copyright (C) 1991-2003 The National Gallery

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 */

/*

    These files are distributed with VIPS - http://www.vips.ecs.soton.ac.uk

*/

#define TYPE_TOGGLEVIEW (toggleview_get_type())
#define TOGGLEVIEW( obj ) (GTK_CHECK_CAST( (obj), TYPE_TOGGLEVIEW, Toggleview ))
#define TOGGLEVIEW_CLASS( klass ) \
	(GTK_CHECK_CLASS_CAST( (klass), TYPE_TOGGLEVIEW, ToggleviewClass ))
#define IS_TOGGLEVIEW( obj ) (GTK_CHECK_TYPE( (obj), TYPE_TOGGLEVIEW ))
#define IS_TOGGLEVIEW_CLASS( klass ) \
	(GTK_CHECK_CLASS_TYPE( (klass), TYPE_TOGGLEVIEW ))

typedef struct _Toggleview {
	Graphicview parent_object;

	/* My instance vars.
	 */
	GtkWidget *toggle;
} Toggleview;

typedef struct _ToggleviewClass {
	GraphicviewClass parent_class;

	/* My methods.
	 */
} ToggleviewClass;

GtkType toggleview_get_type( void );
View *toggleview_new( void );

==> nip-7.8.14.tar.gz: nip-7.8.14/src/toggleview.h <==
/* a toggleview button in a workspace
 */

/*

    Copyright (C) 1991-2003 The National Gallery

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 */

/*

    These files are distributed with VIPS - http://www.vips.ecs.soton.ac.uk

*/

#define TYPE_TOGGLEVIEW (toggleview_get_type())
#define TOGGLEVIEW( obj ) (GTK_CHECK_CAST( (obj), TYPE_TOGGLEVIEW, Toggleview ))
#define TOGGLEVIEW_CLASS( klass ) \
	(GTK_CHECK_CLASS_CAST( (klass), TYPE_TOGGLEVIEW, ToggleviewClass ))
#define IS_TOGGLEVIEW( obj ) (GTK_CHECK_TYPE( (obj), TYPE_TOGGLEVIEW ))
#define IS_TOGGLEVIEW_CLASS( klass ) \
	(GTK_CHECK_CLASS_TYPE( (klass), TYPE_TOGGLEVIEW ))

typedef struct _Toggleview {
	View view;

	/* My instance vars.
	 */
	GtkWidget *toggle;
} Toggleview;

typedef struct _ToggleviewClass {
	ViewClass parent_class;

	/* My methods.
	 */
} ToggleviewClass;

GtkType toggleview_get_type( void );
View *toggleview_new( void );
